
# This file was automatically generated by Dist::Zilla::Plugin::ModuleBuild v6.010.
use strict;
use warnings;

use Module::Build 0.28;


my %module_build_args = (
  "build_requires" => {
    "Module::Build" => "0.28"
  },
  "configure_requires" => {
    "ExtUtils::MakeMaker" => 0,
    "Module::Build" => "0.28",
    "perl" => "v5.10.0"
  },
  "dist_abstract" => "given an ip block in cidr notation, show all reverse IP lookups",
  "dist_author" => [
    "Kevin Phair <phair.kevin\@gmail.com>"
  ],
  "dist_name" => "App-showreverse",
  "dist_version" => "0.0.3",
  "license" => "bsd",
  "module_name" => "App::showreverse",
  "recursive_test_files" => 1,
  "requires" => {
    "App::Cmd::Simple" => 0,
    "Net::CIDR" => "0.18",
    "Net::DNS" => "1.01",
    "Net::Works::Network" => "0.21",
    "autodie" => 0,
    "base" => 0,
    "perl" => "v5.10.0",
    "strict" => 0,
    "warnings" => 0
  },
  "test_requires" => {
    "perl" => "v5.10.0"
  }
);


my %fallback_build_requires = (
  "Module::Build" => "0.28",
  "perl" => "v5.10.0"
);


unless ( eval { Module::Build->VERSION(0.4004) } ) {
  delete $module_build_args{test_requires};
  $module_build_args{build_requires} = \%fallback_build_requires;
}

my $build = Module::Build->new(%module_build_args);


$build->create_build_script;
